@@ -166,7 +166,7 @@ int32_t SPNATIVE__SPVM__Util__isdigit(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memcpyb(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memcpy_byte(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) {
@@ -210,7 +210,7 @@ int32_t SPNATIVE__SPVM__Util__memcpyb(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memmoveb(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memmove_byte(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -250,7 +250,7 @@ int32_t SPNATIVE__SPVM__Util__memmoveb(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memcpys(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memcpy_short(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -290,7 +290,7 @@ int32_t SPNATIVE__SPVM__Util__memcpys(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memmoves(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memmove_short(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -330,7 +330,7 @@ int32_t SPNATIVE__SPVM__Util__memmoves(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memcpyi(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memcpy_int(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -370,7 +370,7 @@ int32_t SPNATIVE__SPVM__Util__memcpyi(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memmovei(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memmove_int(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -410,7 +410,7 @@ int32_t SPNATIVE__SPVM__Util__memmovei(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memcpyl(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memcpy_long(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -450,7 +450,7 @@ int32_t SPNATIVE__SPVM__Util__memcpyl(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memmovel(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memmove_long(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -490,7 +490,7 @@ int32_t SPNATIVE__SPVM__Util__memmovel(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memcpyf(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memcpy_float(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -530,7 +530,7 @@ int32_t SPNATIVE__SPVM__Util__memcpyf(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memmovef(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memmove_float(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -570,7 +570,7 @@ int32_t SPNATIVE__SPVM__Util__memmovef(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memcpyd(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memcpy_double(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -610,7 +610,7 @@ int32_t SPNATIVE__SPVM__Util__memcpyd(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__memmoved(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__Util__memmove_double(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dest_data = stack[0].oval;
   if (!obj_dest_data) { return env->die(env, "Dist string must be defined", MFILE, __LINE__); }
@@ -713,172 +713,6 @@ int32_t SPNATIVE__SPVM__Util__new_object_array_proto(SPVM_ENV* env, SPVM_VALUE*
   return 0;
 }
 
-int32_t SPNATIVE__SPVM__Util__reverseb(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* onums = stack[0].oval;
-  
-  if (onums == NULL) {
-    return env->die(env, "Array must be defined", MFILE, __LINE__);
-  }
-
-  int32_t array_length = env->length(env, onums);
-  if (array_length == 0) {
-    return 0;
-  }
-  
-  int8_t* nums = env->get_elems_byte(env, onums);
-  
-  for(int32_t i = 0; i < array_length / 2; i++){
-    int8_t tmp = nums[i];
-    nums[i] = nums[array_length - i - 1];
-    nums[array_length - i - 1] = tmp;
-  }
-  
-  return 0;
-}
-
-int32_t SPNATIVE__SPVM__Util__reverses(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* onums = stack[0].oval;
-  
-  if (onums == NULL) {
-    return env->die(env, "Array must be defined", MFILE, __LINE__);
-  }
-
-  int32_t array_length = env->length(env, onums);
-  if (array_length == 0) {
-    return 0;
-  }
-  
-  int16_t* nums = env->get_elems_short(env, onums);
-  
-  for(int32_t i = 0; i < array_length / 2; i++){
-    int16_t tmp = nums[i];
-    nums[i] = nums[array_length - i - 1];
-    nums[array_length - i - 1] = tmp;
-  }
-  
-  return 0;
-}
-
-int32_t SPNATIVE__SPVM__Util__reversei(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* onums = stack[0].oval;
-  
-  if (onums == NULL) {
-    return env->die(env, "Array must be defined", MFILE, __LINE__);
-  }
-
-  int32_t array_length = env->length(env, onums);
-  if (array_length == 0) {
-    return 0;
-  }
-  
-  int32_t* nums = env->get_elems_int(env, onums);
-  
-  for(int32_t i = 0; i < array_length / 2; i++){
-    int32_t tmp = nums[i];
-    nums[i] = nums[array_length - i - 1];
-    nums[array_length - i - 1] = tmp;
-  }
-  
-  return 0;
-}
-
-int32_t SPNATIVE__SPVM__Util__reversel(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* onums = stack[0].oval;
-  
-  if (onums == NULL) {
-    return env->die(env, "Array must be defined", MFILE, __LINE__);
-  }
-
-  int32_t array_length = env->length(env, onums);
-  if (array_length == 0) {
-    return 0;
-  }
-  
-  int64_t* nums = env->get_elems_long(env, onums);
-  
-  for(int32_t i = 0; i < array_length / 2; i++){
-    int64_t tmp = nums[i];
-    nums[i] = nums[array_length - i - 1];
-    nums[array_length - i - 1] = tmp;
-  }
-  
-  return 0;
-}
-
-int32_t SPNATIVE__SPVM__Util__reversef(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* onums = stack[0].oval;
-  
-  if (onums == NULL) {
-    return env->die(env, "Array must be defined", MFILE, __LINE__);
-  }
-
-  int32_t array_length = env->length(env, onums);
-  if (array_length == 0) {
-    return 0;
-  }
-  
-  float* nums = env->get_elems_float(env, onums);
-  
-  for(int32_t i = 0; i < array_length / 2; i++){
-    float tmp = nums[i];
-    nums[i] = nums[array_length - i - 1];
-    nums[array_length - i - 1] = tmp;
-  }
-  
-  return 0;
-}
-
-int32_t SPNATIVE__SPVM__Util__reversed(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* onums = stack[0].oval;
-  
-  if (onums == NULL) {
-    return env->die(env, "Array must be defined", MFILE, __LINE__);
-  }
-
-  int32_t array_length = env->length(env, onums);
-  if (array_length == 0) {
-    return 0;
-  }
-  
-  double* nums = env->get_elems_double(env, onums);
-  
-  for(int32_t i = 0; i < array_length / 2; i++){
-    double tmp = nums[i];
-    nums[i] = nums[array_length - i - 1];
-    nums[array_length - i - 1] = tmp;
-  }
-  
-  return 0;
-}
-
-int32_t SPNATIVE__SPVM__Util__reverseo(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* onums = stack[0].oval;
-  
-  if (onums == NULL) {
-    return env->die(env, "Array must be defined", MFILE, __LINE__);
-  }
-
-  int32_t array_length = env->length(env, onums);
-  if (array_length == 0) {
-    return 0;
-  }
-  
-  for(int32_t i = 0; i < array_length / 2; i++){
-    void* tmp = env->get_elem_object(env, onums, i);
-    env->set_elem_object(env, onums, i, env->get_elem_object(env, onums, array_length - i - 1));
-    env->set_elem_object(env, onums, array_length - i - 1, tmp);
-  }
-  
-  return 0;
-}
-
 int32_t SPNATIVE__SPVM__Util__FLT_MAX(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
