@@ -24,14 +24,14 @@ SPVM::Util - Variouse utilities
   {
     my $re_values = [1.5f, 2.5f, 3.5f];
     my $im_values = [5.5f, 6.5f, 7.5f];
-    my $farray = complex_farray($re_values, $im_values);
+    my $farray = complex_float_array($re_values, $im_values);
   }
 
   # Create a new double complex array
   {
     my $re_values = [1.5, 2.5, 3.5];
     my $im_values = [5.5, 6.5, 7.5];
-    my $farray = complex_darray($re_values, $im_values);
+    my $farray = complex_double_array($re_values, $im_values);
   }
   
   # Create a new float complex value
@@ -47,7 +47,7 @@ SPVM::Util - Variouse utilities
   # Copy a byte array
   {
     my $nums = [(byte)1, 2, 3];
-    my $nums_copy = copy_barray($nums);
+    my $nums_copy = copy_byte_array($nums);
   }
 
   # Copy a string
@@ -59,86 +59,86 @@ SPVM::Util - Variouse utilities
   # Copy a short array
   {
     my $nums = [(short)1, 2, 3];
-    my $nums_copy = copy_sarray($nums);
+    my $nums_copy = copy_short_array($nums);
   }
 
   # Copy a int array
   {
     my $nums = [1, 2, 3];
-    my $nums_copy = copy_iarray($nums);
+    my $nums_copy = copy_int_array($nums);
   }
 
   # Copy a long array
   {
     my $nums = [(long)1, 2, 3];
-    my $nums_copy = copy_larray($nums);
+    my $nums_copy = copy_long_array($nums);
   }
 
   # Copy a float array
   {
     my $nums = [1.5f, 2.5f, 3.5f];
-    my $nums_copy = copy_farray($nums);
+    my $nums_copy = copy_float_array($nums);
   }
 
   # Copy a double array
   {
     my $nums = [1.5, 2.5, 3.5];
-    my $nums_copy = copy_darray($nums);
+    my $nums_copy = copy_double_array($nums);
   }
   
   # Copy a string array
   {
     my $strs = ["abc", "def", "ghi"]
-    my $strs_copy = copy_strarray($strs);
+    my $strs_copy = copy_string_array($strs);
   }
   
   # Check if the two byte arrays equal
   {
     my $nums1 = [(byte)1, 2];
     my $nums2 = [(byte)1, 2];
-    my $ret = equals_barray($nums1, $nums2);
+    my $ret = equals_byte_array($nums1, $nums2);
   }
 
   # Check if the two short arrays equal
   {
     my $nums1 = [(short)1, 2];
     my $nums2 = [(short)1, 2];
-    my $ret = equals_sarray($nums1, $nums2);
+    my $ret = equals_short_array($nums1, $nums2);
   }
 
   # Check if the two int arrays equal
   {
     my $nums1 = [(int)1, 2];
     my $nums2 = [(int)1, 2];
-    my $ret = equals_iarray($nums1, $nums2);
+    my $ret = equals_int_array($nums1, $nums2);
   }
 
   # Check if the two long arrays equal
   {
     my $nums1 = [(long)1, 2];
     my $nums2 = [(long)1, 2];
-    my $ret = equals_larray($nums1, $nums2);
+    my $ret = equals_long_array($nums1, $nums2);
   }
 
   # Check if the two float arrays equal
   {
     my $nums1 = [(float)1, 2];
     my $nums2 = [(float)1, 2];
-    my $ret = equals_farray($nums1, $nums2);
+    my $ret = equals_float_array($nums1, $nums2);
   }
 
   # Check if the two double arrays equal
   {
     my $nums1 = [(double)1, 2];
     my $nums2 = [(double)1, 2];
-    my $ret = equals_darray($nums1, $nums2);
+    my $ret = equals_double_array($nums1, $nums2);
   }
 
   # Check if the two string arrays equal
   {
     my $strs1 = ["abc", "def"];
     my $strs2 = ["abc", "def"];
-    my $ret = equals_strarray($strs1, $strs2);
+    my $ret = equals_string_array($strs1, $strs2);
   }
   
   # Search substr
@@ -148,7 +148,7 @@ SPVM::Util - Variouse utilities
 
   # Copy object array
   my $objects = [(object)SPVM::Int->new(1), SPVM::Int->new(2), SPVM::Int->new(3)];
-  my $objects_copy = copy_oarray($objects, sub : object ($self : self, $obj : object) {
+  my $objects_copy = copy_object_array($objects, sub : object ($self : self, $obj : object) {
     my $int_obj = (SPVM::Int)$obj;
     my $new_int_obj = SPVM::Int->new($int_obj->val);
     return $new_int_obj;
@@ -156,7 +156,7 @@ SPVM::Util - Variouse utilities
   
   # Stringify all object and join them by the specific separator
   my $objects = new Foo[3];
-  my $str = SPVM::Util->joino(",", $objects, sub : string ($self : self, $obj : object) {
+  my $str = SPVM::Util->join_object(",", $objects, sub : string ($self : self, $obj : object) {
     my $point = (SPVM::Point)$obj;
     my $x = $point->x;
     my $y = $point->y;
@@ -176,15 +176,15 @@ Unix standard library.
 
 =head1 STATIC METHODS
 
-=head2 copy_oarray
+=head2 copy_object_array
 
-  sub copy_oarray : object[] ($objects : object[], $cloner : SPVM::Cloner)
+  sub copy_object_array : object[] ($objects : object[], $cloner : SPVM::Cloner)
 
 Copy object array. You must specify a L<SPVM::Cloner> object to copy each element.
 
-=head2 equals_oarray
+=head2 equals_object_array
 
-  sub sub equals_oarray : int ($objs1 : oarray, $objs2 : oarray, $equality_checker : SPVM::EqualityChecker)
+  sub sub equals_object_array : int ($objs1 : oarray, $objs2 : oarray, $equality_checker : SPVM::EqualityChecker)
 
 Check equality of two objects. You must sepecify a L<SPVM::EqualityChecker> object to check the equality of each element.
 
@@ -192,9 +192,9 @@ $objs1 and $objs2 and $equality_checker must be defined, otherwise a exception o
 
 Return 1 if the length of $objs1 and $objs2 is same and all element is same, otherwise return 0.
 
-=head2 joino
+=head2 join_object
 
-  sub joino : string ($sep : string, $objects : oarray, $stringer : SPVM::Stringer)
+  sub join_object : string ($sep : string, $objects : oarray, $stringer : SPVM::Stringer)
 
 Stringify all objects and join them by specific separator.
 You must specify a L<SPVM::Stringer> object to stringify each element.
@@ -221,15 +221,15 @@ Copy the string and remove the newline "\n" from the end of string and return it
 
 Copy the string and remove the newline "\r\n" from the end of string and return it.
 
-=head2 complex_farray
+=head2 complex_float_array
 
-  sub complex_farray : SPVM::Complex_2f[] ($re_values : float[], $im_values : float[])
+  sub complex_float_array : SPVM::Complex_2f[] ($re_values : float[], $im_values : float[])
 
 Create a new array of L<SPVM::Complex_2f> with real values and imaginary values.
 
-=head2 complex_darray
+=head2 complex_double_array
 
-  sub complex_darray : SPVM::Complex_2d[] ($re_values : double[], $im_values : double[])
+  sub complex_double_array : SPVM::Complex_2d[] ($re_values : double[], $im_values : double[])
 
 Create a new array of L<SPVM::Complex_2d> with real values and imaginary values.
 
@@ -245,9 +245,9 @@ sub complexd : SPVM::Complex_2d ($re : double, $im : double)
 
 Return a new value of L<SPVM::Complex_2d>.
 
-=head2 copy_barray
+=head2 copy_byte_array
 
-  sub copy_barray : byte[] ($nums : byte[])
+  sub copy_byte_array : byte[] ($nums : byte[])
 
 Copy a byte array.
 
@@ -261,105 +261,105 @@ Copy a string.
 
 If the array is undefined, a exception occurs.
 
-=head2 copy_sarray
+=head2 copy_short_array
 
-  sub copy_sarray : short[] ($nums : short[])
+  sub copy_short_array : short[] ($nums : short[])
 
 Copy a short array.
 
 If the array is undefined, a exception occurs.
   
-=head2 copy_iarray
+=head2 copy_int_array
 
-  sub copy_iarray : int[] ($nums : int[])
+  sub copy_int_array : int[] ($nums : int[])
 
 Copy a int array.
 
 If the array is undefined, a exception occurs.
   
-=head2 copy_larray
+=head2 copy_long_array
 
-  sub copy_larray : long[] ($nums : long[])
+  sub copy_long_array : long[] ($nums : long[])
 
 Copy a long array.
 
 If the array is undefined, a exception occurs.
 
-=head2 copy_farray
+=head2 copy_float_array
 
-  sub copy_farray : float[] ($nums : float[])
+  sub copy_float_array : float[] ($nums : float[])
 
 Copy a float array.
 
 If the array is undefined, a exception occurs.
 
-=head2 copy_darray
+=head2 copy_double_array
 
-  sub copy_darray : double[] ($nums : double[])
+  sub copy_double_array : double[] ($nums : double[])
 
 Copy a double array.
 
 If the array is undefined, a exception occurs.
 
-=head2 copy_strarray
+=head2 copy_string_array
 
-  sub copy_strarray : string[] ($strings : string[])
+  sub copy_string_array : string[] ($strings : string[])
 
 Copy a string array.
 
 If the array is undefined, a exception occurs.
 
-=head2 equals_barray
+=head2 equals_byte_array
 
-  sub equals_barray : int ($nums1 : byte[], $nums2 : byte[])
+  sub equals_byte_array : int ($nums1 : byte[], $nums2 : byte[])
 
 Check if two byte arrays equal.
 
 If at least one of the arrays is undefined, a excetpion occurs.
 
-=head2 equals_sarray
+=head2 equals_short_array
 
-  sub equals_sarray : int ($nums1 : short[], $nums2 : short[])
+  sub equals_short_array : int ($nums1 : short[], $nums2 : short[])
 
 Check if two short arrays equal.
 
 If at least one of the arrays is undefined, a excetpion occurs.
 
-=head2 equals_iarray
+=head2 equals_int_array
 
-  sub equals_iarray : int ($nums1 : int[], $nums2 : int[])
+  sub equals_int_array : int ($nums1 : int[], $nums2 : int[])
 
 Check if two int arrays equal.
 
 If at least one of the arrays is undefined, a excetpion occurs.
 
-=head2 equals_larray
+=head2 equals_long_array
 
-  sub equals_larray : int ($nums1 : long[], $nums2 : long[])
+  sub equals_long_array : int ($nums1 : long[], $nums2 : long[])
 
 Check if two long arrays equal.
 
 If at least one of the arrays is undefined, a excetpion occurs.
 
-=head2 equals_farray
+=head2 equals_float_array
 
-  sub equals_farray : int ($nums1 : float[], $nums2 : float[])
+  sub equals_float_array : int ($nums1 : float[], $nums2 : float[])
 
 Check if two float arrays equal.
 
 If at least one of the arrays is undefined, a excetpion occurs.
 
-=head2 equals_darray
+=head2 equals_double_array
 
-  sub equals_darray : int ($nums1 : double[], $nums2 : double[])
+  sub equals_double_array : int ($nums1 : double[], $nums2 : double[])
 
 Check if two double arrays equal.
 
 If at least one of the arrays is undefined, a excetpion occurs.
 
-=head2 equals_strarray
+=head2 equals_string_array
 
-  sub equals_strarray : int ($strs1 : double[], $strs2 : double[])
+  sub equals_string_array : int ($strs1 : double[], $strs2 : double[])
 
 Check if two string arrays equal.
 
@@ -391,75 +391,99 @@ returns -1.
             
 =head2 INT8_MIN
 
-B<sub INT8_MIN : byte ()>
+  sub INT8_MIN : byte ()
 
-Wapper of INT8_MIN of C99 cstdint library.
+byte(8bit integer) min value. return -128.
 
 =head2 INT8_MAX
 
-B<INT8_MAX : byte ()>
+  INT8_MAX : byte ()
 
-Wapper of INT8_MAX of C99 cstdint library.
+byte(8bit integer) max value. return 127.
 
 =head2 INT16_MIN
 
-B<sub INT16_MIN : short ()>
+  sub INT16_MIN : short ()
 
-Wapper of INT16_MIN of C99 cstdint library.
+short(16bit integer) min value. return -32768.
 
 =head2 INT16_MAX
 
-B<sub INT16_MAX : short ()>
+  sub INT16_MAX : short ()
 
-Wapper of INT16_MAX of C99 cstdint library.
+short(16bit integer) max value. return 32767.
 
 =head2 INT32_MIN
 
-B<sub INT32_MIN : int ()>
+  sub INT32_MIN : int ()
 
-Wapper of INT32_MIN of C99 cstdint library.
+int(32bit integer) min value. return -2147483648.
 
 =head2 INT32_MAX
 
-B<sub INT32_MAX : int ()>
+  sub INT32_MAX : int ()
 
-Wapper of INT32_MAX of C99 cstdint library.
+int(32bit integer) max value. return 2147483647.
 
 =head2 INT64_MIN
 
-B<sub INT64_MIN : long ()>
+  sub INT64_MIN : long ()
 
-Wapper of INT64_MIN of C99 cstdint library.
+long(64bit integer) min value. return -9223372036854775808.
 
 =head2 INT64_MAX
 
-B<sub INT64_MAX : long ()>
+  sub INT64_MAX : long ()
 
-Wapper of INT64_MAX of C99 cstdint library.
+long(64bit integer) max value. return 9223372036854775807.
+
+=head2 UINT8_MAX
+
+  sub UINT8_MAX : byte ()
+
+return -1. This is same as bit expression of 0xFF in unsigned 8bit integer in 2's complement.
+
+=head2 UINT16_MAX
+
+  sub UINT16_MAX : short ()
+
+return -1. This is same as bit expression of 0xFFFF in unsigned 8bit integer in 2's complement.
+
+=head2 UINT32_MAX
+
+  sub UINT32_MAX : int ()
+
+return -1. This is same as bit expression of 0xFFFFFFFF in unsigned 8bit integer in 2's complement.
+
+=head2 UINT64_MAX
+
+  sub UINT64_MAX : long ()
+
+return -1. This is same as bit expression of 0xFFFFFFFFFFFFFFFF in unsigned 8bit integer in 2's complement.
 
 =head2 FLT_MIN
 
-B<sub FLT_MIN : float ()>
+  sub FLT_MIN : float ()
 
-Wapper of FLT_MIN of C99 float library.
+return the value of FLT_MIN macro of float.h C library.
 
 =head2 FLT_MAX
 
-B<sub FLT_MAX : float ()>
+  sub FLT_MAX : float ()
 
-Wapper of FLT_MAX of C99 float library.
+return the value of FLT_MAX macro of float.h C library.
 
 =head2 DBL_MIN
 
-B<sub DBL_MIN : double ()>
+  sub DBL_MIN : double ()
 
-Wapper of DBL_MIN of C99 float library.
+return the value of DBL_MIN macro of float.h C library.
 
 =head2 DBL_MAX
 
-B<sub DBL_MAX : double ()>
+  sub DBL_MAX : double ()
 
-Wapper of DBL_MAX of C99 float library.
+return the value of DBL_MAX macro of float.h C library.
 
 =head2 isalnum
 
@@ -557,65 +581,89 @@ If character is Perl space character(' ', '\r', '\n', '\t', '\f'), return 1. If
 
 If character is Perl word character('a'-'z', 'A'-'Z', '_', '0'-'9'), return 1. If not, return 0.
 
-=head2 joinb
+=head2 dump_byte_array
 
-  sub joinb : string ($sep : string, $nums : byte[])
+  sub dump_byte_array : string ($nums : byte[])
   
-Join a byte array as string with separater and return it.
+Convert the elements in the byte array to string and join them with "," and surround it with "[" and "]", and return it.
 
-If separater is undef, a exception occurs.
+If byte array is undef, return undef.
 
-If byte array is undef, a exception occurs.
+=head2 dump_short_array
 
-=head2 joins
-
-  sub joins : string ($sep : string, $nums : short[])
+  sub dump_short_array : string ($nums : short[])
   
-Join a short array as string with separater and return it.
+Convert the elements in the short array to string and join them with "," and surround it with "[" and "]".
 
-If separater is undef, a exception occurs.
+For Easy-to-read spaces and line breaks are inserted.
 
-If short array is undef, a exception occurs.
+If byte array is undef, return undef.
 
-=head2 joini
+=head2 dump_int_array
 
-  sub joini : string ($sep : string, $nums : int[])
+  sub dump_int_array : string ($nums : int[])
   
-Join a int array as string with separater and return it.
+Convert the elements in the int array to string and join them with "," and surround it with "[" and "]", and return it.
 
-If separater is undef, a exception occurs.
+If byte array is undef, return undef.
 
-If int array is undef, a exception occurs.
+=head2 dump_long_array
 
-=head2 joinl
-
-  sub joinl : string ($sep : string, $nums : long[])
+  sub dump_long_array : string ($nums : long[])
   
-Join a long array as string with separater and return it.
+Convert the elements in the long array to string and join them with "," and surround it with "[" and "]", and return it.
 
-If separater is undef, a exception occurs.
+If byte array is undef, return undef.
 
-If long array is undef, a exception occurs.
+=head2 dump_unsigned_byte_array
 
-=head2 joinf
-
-  sub joinf : string ($sep : string, $nums : float[])
+  sub dump_unsigned_byte_array : string ($nums : byte[])
   
-Join a float array as string with separater and return it.
+Convert the elements in the byte array to string interpreting as an unsigned 8bit integer and join them with "," and surround it with "[" and "]", and return it.
 
-If separater is undef, a exception occurs.
+If byte array is undef, return undef.
 
-If float array is undef, a exception occurs.
+=head2 dump_unsigned_short_array
 
-=head2 joind
-
-  sub joind : string ($sep : string, $nums : double[])
+  sub dump_unsigned_short_array : string ($nums : short[])
   
-Join a double array as string with separater and return it.
+Convert the elements in the short array to string interpreting as an unsigned 16bit integer and join them with "," and surround it with "[" and "]".
 
-If separater is undef, a exception occurs.
+For Easy-to-read spaces and line breaks are inserted.
 
-If double array is undef, a exception occurs.
+If byte array is undef, return undef.
+
+=head2 dump_unsigned_int_array
+
+  sub dump_unsigned_int_array : string ($nums : int[])
+  
+Convert the elements in the int array to string interpreting as an unsigned 32bit integer and join them with "," and surround it with "[" and "]", and return it.
+
+If byte array is undef, return undef.
+
+=head2 dump_unsigned_long_array
+
+  sub dump_unsigned_long_array : string ($nums : long[])
+  
+Convert the elements in the long array to string interpreting as an unsigned 64bit integer and join them with "," and surround it with "[" and "]", and return it.
+
+If byte array is undef, return undef.
+
+=head2 dump_float_array
+
+  sub dump_float_array : string ($nums : float[])
+  
+Convert the elements in the float array to string and join them with "," and surround it with "[" and "]", and return it.
+
+If byte array is undef, return undef.
+
+=head2 dump_double_array
+
+  sub dump_double_array : string ($nums : double[])
+  
+Convert the elements in the double array to string and join them with "," and surround it with "[" and "]", and return it.
+
+If byte array is undef, return undef.
 
 =head2 join
 
@@ -639,9 +687,9 @@ Convert uppercase string to lowercase string.
 
 Convert first chracter of string from uppercase to lowercase.
 
-=head2 memcpyb
+=head2 memcpy_byte
 
-  sub memcpyb : void ($dest_data : byte[], $dest_offset : int, $src_data : byte[], $src_offset : int, $length : int)
+  sub memcpy_byte : void ($dest_data : byte[], $dest_offset : int, $src_data : byte[], $src_offset : int, $length : int)
 
 Copy source byte array to destination byte array with the each offset and a length.
 
@@ -655,9 +703,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memcpys
+=head2 memcpy_short
 
-  sub memcpys : void ($dest_data : short[], $dest_offset : int, $src_data : short[], $src_offset : int, $length : int)
+  sub memcpy_short : void ($dest_data : short[], $dest_offset : int, $src_data : short[], $src_offset : int, $length : int)
 
 Copy source short array to destination short array with the each offset and a length.
 
@@ -671,9 +719,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memcpyi
+=head2 memcpy_int
   
-  sub memcpyi : void ($dest_data : int[], $dest_offset : int, $src_data : int[], $src_offset : int, $length : int)
+  sub memcpy_int : void ($dest_data : int[], $dest_offset : int, $src_data : int[], $src_offset : int, $length : int)
 
 Copy source int array to destination int array with the each offset and a length.
 
@@ -687,9 +735,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memcpyl
+=head2 memcpy_long
   
-  sub memcpyl : void ($dest_data : long[], $dest_offset : int, $src_data : long[], $src_offset : int, $length : int)
+  sub memcpy_long : void ($dest_data : long[], $dest_offset : int, $src_data : long[], $src_offset : int, $length : int)
 
 Copy source long array to destination long array with the each offset and a length.
 
@@ -703,9 +751,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memcpyf
+=head2 memcpy_float
   
-  sub memcpyf : void ($dest_data : float[], $dest_offset : int, $src_data : float[], $src_offset : int, $length : int)
+  sub memcpy_float : void ($dest_data : float[], $dest_offset : int, $src_data : float[], $src_offset : int, $length : int)
 
 Copy source float array to destination float array with the each offset and a length.
 
@@ -719,9 +767,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memcpyd
+=head2 memcpy_double
   
-  sub memcpyd : void ($dest_data : double[], $dest_offset : int, $src_data : double[], $src_offset : int, $length : int)
+  sub memcpy_double : void ($dest_data : double[], $dest_offset : int, $src_data : double[], $src_offset : int, $length : int)
 
 Copy source double array to destination double array with the each offset and a length.
 
@@ -735,9 +783,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memmoveb
+=head2 memmove_byte
 
-  sub memmoveb : void ($dest_data : byte[], $dest_offset : int, $src_data : byte[], $src_offset : int, $length : int)
+  sub memmove_byte : void ($dest_data : byte[], $dest_offset : int, $src_data : byte[], $src_offset : int, $length : int)
 
 Copy source byte array to destination byte array with the each offset and a length.
 
@@ -751,9 +799,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memmoves
+=head2 memmove_short
 
-  sub memmoves : void ($dest_data : short[], $dest_offset : int, $src_data : short[], $src_offset : int, $length : int)
+  sub memmove_short : void ($dest_data : short[], $dest_offset : int, $src_data : short[], $src_offset : int, $length : int)
 
 Copy source short array to destination short array with the each offset and a length.
 
@@ -767,9 +815,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memmovei
+=head2 memmove_int
   
-  sub memmovei : void ($dest_data : int[], $dest_offset : int, $src_data : int[], $src_offset : int, $length : int)
+  sub memmove_int : void ($dest_data : int[], $dest_offset : int, $src_data : int[], $src_offset : int, $length : int)
 
 Copy source int array to destination int array with the each offset and a length.
 
@@ -783,9 +831,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memmovel
+=head2 memmove_long
   
-  sub memmovel : void ($dest_data : long[], $dest_offset : int, $src_data : long[], $src_offset : int, $length : int)
+  sub memmove_long : void ($dest_data : long[], $dest_offset : int, $src_data : long[], $src_offset : int, $length : int)
 
 Copy source long array to destination long array with the each offset and a length.
 
@@ -799,9 +847,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memmovef
+=head2 memmove_float
   
-  sub memmovef : void ($dest_data : float[], $dest_offset : int, $src_data : float[], $src_offset : int, $length : int)
+  sub memmove_float : void ($dest_data : float[], $dest_offset : int, $src_data : float[], $src_offset : int, $length : int)
 
 Copy source float array to destination float array with the each offset and a length.
 
@@ -815,9 +863,9 @@ If length is nagative, a exception occurs.
 
 If copy is not in the valid rainge, a exception occurs.
 
-=head2 memmoved
+=head2 memmove_double
   
-  sub memmoved : void ($dest_data : double[], $dest_offset : int, $src_data : double[], $src_offset : int, $length : int)
+  sub memmove_double : void ($dest_data : double[], $dest_offset : int, $src_data : double[], $src_offset : int, $length : int)
 
 Copy source double array to destination double array with the each offset and a length.
 
@@ -985,65 +1033,3 @@ Get the abusolute value of a int value.
   sub labs : long ($x : long);
 
 Get the abusolute value for a long value.
-
-=head2 reverseb
-
-  native sub reverseb : void ($nums : byte[]);
-
-Reverse the order of the elements of the byte array.
-
-If the argument is undef, a exception occurs.
-
-=head2 reverses
-
-  native sub reverses : void ($nums : short[]);
-
-Reverse the order of the elements of the short array.
-
-If the argument is undef, a exception occurs.
-
-=head2 reversei
-
-  native sub reversei : void ($nums : int[]);
-
-Reverse the order of the elements of the int array.
-
-If the argument is undef, a exception occurs.
-
-=head2 reversel
-
-  native sub reversel : void ($nums : long[]);
-
-Reverse the order of the elements of the long array.
-
-If the argument is undef, a exception occurs.
-
-=head2 reversef
-
-  native sub reversef : void ($nums : float[]);
-
-Reverse the order of the elements of the float array.
-
-If the argument is undef, a exception occurs.
-
-=head2 reversed
-
-  native sub reversed : void ($nums : double[]);
-
-Reverse the order of the elements of the double array.
-
-If the argument is undef, a exception occurs.
-
-=head2 reverseo
-
-  native sub reverseo : void ($objs : oarray);
-
-Reverse the order of the elements of the object array.
-
-If the argument is undef, a exception occurs.
-
-=head2 warn
-
-  sub warn : void ($string : string);
-
-Print string with file name and line number to stderr. line break is added to end of string.
